==> bouml_2.26.3.orig.tar.gz: bouml_2.26.3/src/diagram/ClassDiagramView.h <==
// *************************************************************************
//
// Copyleft 2004-2007 Bruno PAGES  .
//
// This file is part of the BOUML Uml Toolkit.
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
// e-mail : bouml@free.fr
// home   : http://bouml.free.fr
//
// *************************************************************************

#ifndef CLASSDIAGRAMVIEW_H
#define CLASSDIAGRAMVIEW_H

#include <qptrdict.h> 

#include "DiagramView.h"

class ClassDiagramWindow;
class DiagramItem;
class UmlCanvas;
class BrowserNode;

class ClassDiagramView : public DiagramView {
  public:
    ClassDiagramView(QWidget * parent, UmlCanvas * canvas, int id);

    virtual void menu(const QPoint&);
    virtual void read(char *, char * k);
    virtual void save(QTextStream & st, QString & warning, bool copy) const;
    
  private:
    ClassDiagramWindow * window() {
      return (ClassDiagramWindow *) parent();
    };
    void add_classview_classes(BrowserNode * cv, const QPoint& p,
			       QPtrDict<DiagramItem> & drawn);
  
  protected:
    virtual void contentsMousePressEvent(QMouseEvent *);
    virtual void dragEnterEvent(QDragEnterEvent *);
    virtual void dropEvent(QDropEvent *);
};

#endif

==> bouml_4.9.3.tar.gz: bouml_4.9.3/src/diagram/ClassDiagramView.h <==
// *************************************************************************
//
// Copyleft 2004-2009 Bruno PAGES  .
//
// This file is part of the BOUML Uml Toolkit.
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
// e-mail : bouml@free.fr
// home   : http://bouml.free.fr
//
// *************************************************************************

#ifndef CLASSDIAGRAMVIEW_H
#define CLASSDIAGRAMVIEW_H

#include <qptrdict.h> 

#include "DiagramView.h"

class ClassDiagramWindow;
class DiagramItem;
class UmlCanvas;
class BrowserNode;

class ClassDiagramView : public DiagramView {
  public:
    ClassDiagramView(QWidget * parent, UmlCanvas * canvas, int id);

    virtual void menu(const QPoint&);
    virtual void read(char *, char * k);
    virtual void save(QTextStream & st, QString & warning, bool copy) const;
    
  private:
    ClassDiagramWindow * window() {
      return (ClassDiagramWindow *) parent();
    };
    void add_classview_classes(BrowserNode *, const QPoint& p,
			       QPtrDict<DiagramItem> & drawn);
    void add_classview_classes(BrowserNode *, QPtrDict<DiagramItem> & drawn,
			       int & x, int & y, int & future_y);
  
  protected:
    virtual void contentsMousePressEvent(QMouseEvent *);
    virtual void dragEnterEvent(QDragEnterEvent *);
    virtual void dropEvent(QDropEvent *);
};

#endif
